Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Database ¶
type Database struct {
Path string `json:"path" yaml:"path,omitempty"`
}
Database holds configurations related to the data persistence mechanism of the CLI tool
type Notifications ¶
type Notifications struct {
Telegram NotificationsTelegram `json:"telegram" yaml:"telegram,omitempty"`
}
Notifications holds configurations related to the notifications mechanisms of the CLI tool
func (*Notifications) MergeWith ¶
func (dcn *Notifications) MergeWith(o Notifications) []error
type NotificationsTelegram ¶
type NotificationsTelegram struct {
Token string `json:"token" yaml:"token,omitempty"`
ID string `json:"id" yaml:"id,omitempty"`
}
NotificationsTelegram holds configurations related to the telegram integration for sending notifications
func (*NotificationsTelegram) MergeWith ¶
func (dcntg *NotificationsTelegram) MergeWith(o NotificationsTelegram) []error
type Platforms ¶
type Platforms struct {
Github PlatformsGithub `json:"github" yaml:"github,omitempty"`
}
Platforms holds configurations related to the platform integrations for individual users
type PlatformsGithub ¶
type PlatformsGithub struct {
ClientID string `json:"clientId" yaml:"clientId,omitempty"`
ClientSecret string `json:"clientSecret" yaml:"clientSecret,omitempty"`
RedirectURI string `json:"redirectUri" yaml:"redirectUri,omitempty"`
}
func (*PlatformsGithub) MergeWith ¶
func (dcpgh *PlatformsGithub) MergeWith(o PlatformsGithub) []error
Click to show internal directories.
Click to hide internal directories.