Documentation
¶
Index ¶
Constants ¶
const VSCodeFileExtension = ".code-workspace"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type VSCode ¶
type VSCode struct {
// Folders represents a list of projects
Folders []VSCodeFolder `json:"folders"`
}
VSCode represents the visual studio code .code-workspace file format
func (VSCode) ToJSON ¶ added in v0.0.4
ToJSON returns a string that can be used as the .code-workspace visual studio code workspace file
type VSCodeFolder ¶
type VSCodeFolder struct {
// Name is a logical user-defined label
Name string `json:"name"`
// Path is the absolute/relative path to the target project directory
Path string `json:"path"`
}
VSCodeFolder represents a single folder in the visual studio code workspace format
type Workspace ¶
type Workspace struct {
Name string `json:"name" yaml:"name"`
Description string `json:"description" yaml:"description"`
Repositories []repository.Repository `json:"repositories" yaml:"repositories"`
}
Workspace represents a project-scoped set of code repos
Click to show internal directories.
Click to hide internal directories.