Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Check ¶
type Check struct {
Method string `json:"method" yaml:"method,omitempty"`
URL string `json:"url" yaml:"url"`
// StatusCode should contain the expected http status code, if not defined,
// status codes starting with 1xx, 2xx, and 3xx will be considered successful,
// and 4xx, and 5xx codes will be considered failures
StatusCode int `json:"statusCode" yaml:"statusCode,omitempty"`
// Headers contains headers key-value pairs that should be present in the
// HTTP headers of the response
Headers map[string]string `json:"headers" yaml:"headers,omitempty"`
// ResponseBody is a regex-supported match with the response body
ResponseBody string `json:"responseBody" yaml:"responseBody,omitempty"`
// contains filtered or unexported fields
}
Check represents a network check
func (*Check) GetObserved ¶
GetObserved returns the response object from the check; if no check has been performed yet, the http.Response will be of zero value with an error
type Network ¶
type Network struct {
Name string `json:"name" yaml:"name,omitempty"`
RegistrationURL string `json:"registrationUrl" yaml:"registrationUrl,omitempty"`
Check Check `json:"check" yaml:"check,omitempty"`
}
Network defines the configuration structure for the `network` property in the configuration file
Click to show internal directories.
Click to hide internal directories.