Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Repository ¶
type Repository struct {
// Description is a user-defined block of text about what this repository
// is for in their context
Description string `json:"description" yaml:"description,omitempty"`
// Name is a user-defined string to identify this repository
Name string `json:"name" yaml:"name,omitempty"`
// Path is the user-defined location to store this repository
Path string `json:"path" yaml:"path,omitempty"`
// URL is the URL to use to clone the repository; if the provided
// URL does not terminate with `.git`, a best-guess should be made to
// convert this to a proper git clone URL
URL string `json:"url" yaml:"url,omitempty"`
// Workspaces is a list of strings that represent the name of the
// logical workspace this repository belongs to
Workspaces []string `json:"workspaces" yaml:"workspaces,omitempty,flow"`
}
Repository represents a code repo
func (Repository) GetPath ¶
func (r Repository) GetPath(rootPath ...string) (string, error)
GetPath returns the path where the repository should be stored; if the `.Path` property is defined, it shall be used, otherwise the returned path will be derived from the hostname and path of the `.URL`
func (Repository) GetWebsiteURL ¶ added in v0.0.16
func (r Repository) GetWebsiteURL() (string, error)
Click to show internal directories.
Click to hide internal directories.