tests

package
v0.1.36 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 10, 2020 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CaptureStdout

func CaptureStdout(fromThis func() error) (string, error)

CaptureStdout captures prints to the standard output from the function :fromThis. :fromThis should return an error to indicate whether the function call was a success; if the error is non-empty, the returned string will be empty (but an empty string with an error indicates a blank input)

Types

This section is empty.

Jump to