Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Check ¶
type Check struct {
// Command is the command to run including arguments
Command []string `json:"command" yaml:"command"`
// ExitCode is the expected exit code we can expect from the command running if defined
ExitCode int `json:"exitCode" yaml:"exitCode"`
// Stdout is the expected output on stdout if defined
Stdout *string `json:"stdout" yaml:"stdout"`
// Stderr is the expected output on stderr if defined
Stderr *string `json:"stderr" yaml:"stderr"`
// contains filtered or unexported fields
}
Check represents a functional check on whether the software exists. It works by running the command as specified in Command and comparing the output with the provided ExitCode, Stdout, and Stderr.
Usage: 1. Use `.Run()` method to run the check, results will be stored in the `.observed` property 1. Use `.Verify()` method to verify that the `.observed` property matches the provided parameters
func (Check) GetObserved ¶
GetObserved returns the observed results, a nil indicates the check has never been run before
Click to show internal directories.
Click to hide internal directories.